package beilv.venue.mapper;


import beilv.venue.domain.BeilvVenue;

import java.util.List;

/**
 * 场馆信息Mapper接口
 * 
 * @author ruoyi
 * @date 2025-01-06
 */
public interface BeilvVenueMapper 
{
    /**
     * 查询场馆信息
     * 
     * @param id 场馆信息主键
     * @return 场馆信息
     */
    public BeilvVenue selectBeilvVenueById(Long id);

    /**
     * 查询场馆信息列表
     * 
     * @param beilvVenue 场馆信息
     * @return 场馆信息集合
     */
    public List<BeilvVenue> selectBeilvVenueList(BeilvVenue beilvVenue);

    /**
     * 新增场馆信息
     * 
     * @param beilvVenue 场馆信息
     * @return 结果
     */
    public int insertBeilvVenue(BeilvVenue beilvVenue);

    /**
     * 修改场馆信息
     * 
     * @param beilvVenue 场馆信息
     * @return 结果
     */
    public int updateBeilvVenue(BeilvVenue beilvVenue);

    /**
     * 删除场馆信息
     * 
     * @param id 场馆信息主键
     * @return 结果
     */
    public int deleteBeilvVenueById(Long id);

    /**
     * 批量删除场馆信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBeilvVenueByIds(String[] ids);
}
